@@ -104,7 +104,7 @@ impl wita::EventHandler for Application {
         println!("ime end composition: {:?}", s);
     }
 
-    fn other(&mut self, params: &wita::OtherParams) -> Option<i32> {
+    fn other(&mut self, params: &wita::OtherParams) -> Option<isize> {
         println!("other: {:?}", params);
         None
     }
