@@ -21,7 +21,7 @@ impl wita::EventHandler for Application {
         state: wita::KeyState,
         _: bool,
     ) {
-        if code.vkey == wita::VirtualKey::Char('T') && state == wita::KeyState::Released {
+        if code.vkey == wita::VirtualKey::F(1) && state == wita::KeyState::Released {
             let flag = !window.is_enabled_ime();
             window.ime(flag);
             if flag {
