@@ -1,5 +1,8 @@
-use crate::bindings::Windows::Win32::{
-    Foundation::*, Graphics::Gdi::*, UI::HiDpi::*, UI::WindowsAndMessaging::*,
+use windows::Win32::{
+    Foundation::*,
+    Graphics::Gdi::*,
+    UI::HiDpi::*,
+    UI::WindowsAndMessaging::*,
 };
 use crate::geometry::*;
 use std::sync::Once;
