@@ -1,4 +1,7 @@
-use crate::bindings::Windows::Win32::{Foundation::*, UI::WindowsAndMessaging::*};
+use windows::Win32::{
+    Foundation::*,
+    UI::WindowsAndMessaging::*,
+};
 use crate::{device::*, event::EventHandler, event::OtherParams, window::LocalWindow};
 use std::any::Any;
 use std::cell::RefCell;
