@@ -1,5 +1,7 @@
-use crate::bindings::Windows::Win32::{
-    Foundation::*, UI::KeyboardAndMouseInput::*, UI::WindowsAndMessaging::*,
+use windows::Win32::{
+    Foundation::*,
+    UI::Input::KeyboardAndMouse::*,
+    UI::WindowsAndMessaging::*,
 };
 use crate::geometry::*;
 #[cfg(feature = "serde")]
@@ -202,9 +204,9 @@ impl KeyCode {
 }
 
 pub fn as_virtual_key(k: u32) -> VirtualKey {
-    const ZERO: u32 = b'0' as _;
-    const Z: u32 = b'Z' as _;
-    match k {
+    const ZERO: u16 = b'0' as _;
+    const Z: u16 = b'Z' as _;
+    match k as u16 {
         v @ ZERO..=Z => VirtualKey::Char((v as u8).into()),
         VK_ESCAPE => VirtualKey::Esc,
         VK_TAB => VirtualKey::Tab,
@@ -262,7 +264,12 @@ pub fn to_raw_virtual_key(k: VirtualKey) -> u32 {
     const ZERO: char = '0' as _;
     const Z: char = 'Z' as _;
     match k {
-        VirtualKey::Char(c) if (ZERO..=Z).contains(&c) => c as u32,
+        VirtualKey::Char(c) if (ZERO..=Z).contains(&c) => return c as u32,
+        VirtualKey::NumPad(n) => return VK_NUMPAD0 as u32 + n as u32,
+        VirtualKey::F(n) => return VK_F1 as u32 + n as u32 - 1,
+        _ => {}
+    }
+    match k {
         VirtualKey::Esc => VK_ESCAPE,
         VirtualKey::Tab => VK_TAB,
         VirtualKey::CapsLock => VK_CAPITAL,
@@ -286,7 +293,6 @@ pub fn to_raw_virtual_key(k: VirtualKey) -> u32 {
         VirtualKey::Left => VK_LEFT,
         VirtualKey::Right => VK_RIGHT,
         VirtualKey::NumLock => VK_NUMLOCK,
-        VirtualKey::NumPad(n) => VK_NUMPAD0 + n as u32,
         VirtualKey::NumAdd => VK_ADD,
         VirtualKey::NumSub => VK_SUBTRACT,
         VirtualKey::NumMul => VK_MULTIPLY,
@@ -310,10 +316,11 @@ pub fn to_raw_virtual_key(k: VirtualKey) -> u32 {
         VirtualKey::Char(']') => VK_OEM_6,
         VirtualKey::Char('^') => VK_OEM_7,
         VirtualKey::Char('_') => VK_OEM_102,
-        VirtualKey::F(n) => VK_F1 + n as u32 - 1,
-        VirtualKey::Other(x) => x,
-        _ => unreachable!(),
-    }
+        _ => match k {
+            VirtualKey::Other(x) => return x,
+            _ => unreachable!(),
+        }
+    }.into()
 }
 
 pub fn get_key_state(k: VirtualKey) -> bool {
@@ -487,7 +494,7 @@ impl Cursor {
     #[inline]
     pub(crate) fn set(&self) {
         unsafe {
-            SetCursor(LoadCursorW(HINSTANCE::NULL, self.name()));
+            SetCursor(LoadCursorW(HINSTANCE::default(), self.name()));
         }
     }
 }
