@@ -1,4 +1,7 @@
-use crate::bindings::Windows::Win32::{System::Diagnostics::Debug::*, System::Memory::*};
+use windows::Win32::{
+    System::Diagnostics::Debug::*,
+    System::Memory::*,
+};
 use std::ptr::{null, null_mut};
 
 #[doc(hidden)]
@@ -10,7 +13,7 @@ macro_rules! last_error {
             file!(),
             line!(),
             $s,
-            $crate::bindings::Windows::Win32::System::Diagnostics::Debug::GetLastError().0
+            windows::core::Error::from_win32().code().0
         )
     };
 }
@@ -45,7 +48,7 @@ pub struct ApiError(u32);
 
 impl ApiError {
     pub fn new() -> Self {
-        unsafe { Self(GetLastError().0) }
+        Self(windows::core::Error::from_win32().code().0 as _)
     }
 
     pub fn code(&self) -> u32 {
