@@ -1,6 +1,6 @@
 #![allow(unused_variables)]
 
-use crate::bindings::Windows::Win32::Foundation::*;
+use windows::Win32::Foundation::*;
 
 #[derive(Debug)]
 pub struct OtherParams {
@@ -120,7 +120,7 @@ pub trait EventHandler {
     ) {
     }
 
-    fn other(&mut self, params: &OtherParams) -> Option<i32> {
+    fn other(&mut self, params: &OtherParams) -> Option<isize> {
         None
     }
 }
