@@ -1,6 +1,10 @@
 //! An IME composition string and a candidate list
 
-use crate::bindings::Windows::Win32::{Foundation::*, Globalization::*};
+use windows::Win32::{
+    Foundation::*,
+    Globalization::*,
+    UI::Input::Ime::*,
+};
 use crate::geometry::*;
 
 /// Describes composition character attributes.
@@ -125,7 +129,7 @@ impl ImmContext {
 
     pub fn disable(&self) {
         unsafe {
-            ImmAssociateContextEx(self.hwnd, HIMC::NULL, IACE_IGNORENOCONTEXT);
+            ImmAssociateContextEx(self.hwnd, HIMC(0), IACE_IGNORENOCONTEXT);
         }
     }
 }
@@ -133,7 +137,7 @@ impl ImmContext {
 impl Drop for ImmContext {
     fn drop(&mut self) {
         unsafe {
-            ImmAssociateContextEx(self.hwnd, HIMC::NULL, IACE_DEFAULT);
+            ImmAssociateContextEx(self.hwnd, HIMC(0), IACE_DEFAULT);
             ImmDestroyContext(self.himc);
         }
     }
