@@ -66,10 +66,6 @@
 //! [`raw_handle`]: struct.Window.html#method.raw_handle
 //!
 
-mod bindings {
-    ::windows::include_bindings!();
-}
-
 mod api;
 mod context;
 mod device;
@@ -95,7 +91,10 @@ pub use monitor::*;
 pub use resource::*;
 pub use window::*;
 
-use bindings::Windows::Win32::{Foundation::*, UI::WindowsAndMessaging::*};
+use windows::Win32::{
+    Foundation::*,
+    UI::WindowsAndMessaging::*,
+};
 use context::*;
 
 /// The value is an unit in logical coordinates.
@@ -121,7 +120,7 @@ where
         RunType::Idle => unsafe {
             while msg.message != WM_QUIT {
                 call_handler(|eh: &mut T, _| eh.pre_processing());
-                if PeekMessageW(&mut msg, HWND::NULL, 0, 0, PM_REMOVE) != BOOL(0) {
+                if PeekMessageW(&mut msg, HWND(0), 0, 0, PM_REMOVE) != BOOL(0) {
                     TranslateMessage(&msg);
                     DispatchMessageW(&msg);
                 } else {
@@ -133,7 +132,7 @@ where
         },
         RunType::Wait => unsafe {
             loop {
-                let ret = GetMessageW(&mut msg, HWND::NULL, 0, 0);
+                let ret = GetMessageW(&mut msg, HWND(0), 0, 0);
                 if ret == BOOL(0) || ret == BOOL(-1) {
                     break;
                 }
