@@ -1,5 +1,7 @@
-use crate::bindings::Windows::Win32::{
-    Foundation::*, Graphics::Gdi::*, UI::WindowsAndMessaging::*,
+use windows::Win32::{
+    Foundation::*,
+    Graphics::Gdi::*,
+    UI::WindowsAndMessaging::*,
 };
 use crate::geometry::*;
 
@@ -48,7 +50,7 @@ pub fn get_monitors() -> Vec<Monitor> {
         let len = GetSystemMetrics(SM_CMONITORS) as usize;
         let mut v = Vec::with_capacity(len);
         EnumDisplayMonitors(
-            HDC::NULL,
+            HDC(0),
             std::ptr::null_mut(),
             Some(get_monitors_proc),
             LPARAM((&mut v) as *mut Vec<Monitor> as _),
@@ -67,7 +69,7 @@ pub fn monitor_from_point(point: ScreenPosition) -> Option<Monitor> {
             },
             MONITOR_DEFAULTTONULL,
         );
-        if hmonitor == HMONITOR::NULL {
+        if hmonitor == HMONITOR(0) {
             return None;
         }
         let mut info = MONITORINFO {
