@@ -1,6 +1,12 @@
-use crate::bindings::Windows::Win32::{
-    Foundation::*, Globalization::*, Graphics::Gdi::*, UI::Controls::WM_MOUSELEAVE, UI::HiDpi::*,
-    UI::KeyboardAndMouseInput::*, UI::Shell::*, UI::WindowsAndMessaging::*,
+use windows::Win32::{
+    Foundation::*,
+    Graphics::Gdi::*,
+    UI::Controls::WM_MOUSELEAVE,
+    UI::HiDpi::*,
+    UI::Input::KeyboardAndMouse::*,
+    UI::Input::Ime::*,
+    UI::Shell::*,
+    UI::WindowsAndMessaging::*,
 };
 #[cfg(feature = "raw_input")]
 use crate::raw_input;
@@ -371,7 +377,7 @@ pub(crate) extern "system" fn window_proc<T: EventHandler + 'static>(
             }
             WM_WINDOWPOSCHANGED => {
                 let pos = &*(lparam.0 as *const WINDOWPOS);
-                if pos.flags.0 & SWP_NOMOVE.0 == 0 {
+                if pos.flags & SWP_NOMOVE == 0 {
                     call_handler(|eh: &mut T, _| {
                         eh.moved(handle, ScreenPosition::new(pos.x, pos.y))
                     });
@@ -424,11 +430,11 @@ pub(crate) extern "system" fn window_proc<T: EventHandler + 'static>(
             }
             WM_DROPFILES => {
                 let hdrop = HDROP(wparam.0 as _);
-                let file_count = DragQueryFileW(hdrop, std::u32::MAX, PWSTR::NULL, 0);
+                let file_count = DragQueryFileW(hdrop, std::u32::MAX, PWSTR::default(), 0);
                 let mut buffer = Vec::new();
                 let files = (0..file_count)
                     .map(|i| {
-                        let len = DragQueryFileW(hdrop, i, PWSTR::NULL, 0) as usize + 1;
+                        let len = DragQueryFileW(hdrop, i, PWSTR::default(), 0) as usize + 1;
                         buffer.resize(len, 0);
                         DragQueryFileW(hdrop, i, PWSTR(buffer.as_mut_ptr()), len as u32);
                         buffer.pop();
