@@ -2,9 +2,12 @@
 //!
 //! To use, specify `"raw_input"` feature.
 
-use crate::bindings::Windows::Win32::{
-    Devices::HumanInterfaceDevice::*, Foundation::*, Storage::FileSystem::*,
-    UI::KeyboardAndMouseInput::*, UI::WindowsAndMessaging::*,
+use windows::Win32::{
+    Foundation::*,
+    Devices::HumanInterfaceDevice::*,
+    Storage::FileSystem::*,
+    UI::Input::*,
+    UI::WindowsAndMessaging::*,
 };
 use crate::context::call_handler;
 use crate::device::*;
@@ -17,14 +20,6 @@ use std::mem::size_of;
 use std::ptr::null_mut;
 use std::rc::Rc;
 
-const FACILITY_HID_ERROR_CODE: u32 = 0x11;
-
-const fn hidp_error_codes(sev: u32, code: u32) -> NTSTATUS {
-    NTSTATUS(((sev << 28) | (FACILITY_HID_ERROR_CODE << 16) | code) as _)
-}
-
-const HIDP_STATUS_SUCCESS: NTSTATUS = hidp_error_codes(0x0, 0);
-
 const HID_USAGE_PAGE_GENERIC: u16 = 0x01;
 
 const HID_USAGE_GENERIC_MOUSE: u16 = 0x02;
@@ -104,14 +99,14 @@ unsafe fn get_device_interface(handle: HANDLE) -> Option<Vec<u16>> {
 unsafe fn get_device_name(interface: &[u16]) -> Option<String> {
     let handle = CreateFileW(
         PWSTR(interface.as_ptr() as _),
-        FILE_ACCESS_FLAGS(0),
-        FILE_SHARE_MODE(FILE_SHARE_READ.0 | FILE_SHARE_WRITE.0),
+        0,
+        FILE_SHARE_READ | FILE_SHARE_WRITE,
         null_mut(),
         OPEN_EXISTING,
-        FILE_FLAGS_AND_ATTRIBUTES(0),
-        HANDLE::NULL,
+        0,
+        HANDLE(0),
     );
-    if handle == HANDLE::NULL {
+    if handle == HANDLE(0) {
         last_error!("get_device_name");
         return None;
     }
@@ -121,7 +116,7 @@ unsafe fn get_device_name(interface: &[u16]) -> Option<String> {
         buffer.as_mut_ptr() as _,
         (buffer.len() * size_of::<u16>()) as _,
     );
-    if ret == 0 {
+    if ret == BOOLEAN(0) {
         CloseHandle(handle);
         return None;
     }
@@ -134,7 +129,7 @@ unsafe fn get_raw_input_device_info(handle: HANDLE) -> Option<RID_DEVICE_INFO> {
     let mut len = size_of::<RID_DEVICE_INFO>() as u32;
     let mut info = RID_DEVICE_INFO {
         cbSize: len as _,
-        dwType: RID_DEVICE_INFO_TYPE(0),
+        dwType: 0,
         Anonymous: RID_DEVICE_INFO_0 {
             keyboard: Default::default(),
         },
@@ -255,24 +250,20 @@ pub fn get_device_info(device: &Device) -> Option<DeviceInfo> {
                 let p = preparsed.as_mut_ptr();
                 let caps = {
                     let mut caps = HIDP_CAPS::default();
-                    let ret = HidP_GetCaps(p as _, &mut caps);
-                    if ret != HIDP_STATUS_SUCCESS {
-                        return None;
-                    }
+                    HidP_GetCaps(p as _, &mut caps).ok()?;
                     caps
                 };
                 let button_caps = {
                     let mut len = caps.NumberInputButtonCaps as u16;
                     let mut caps = Vec::with_capacity(len as _);
                     caps.set_len(len as _);
-                    let ret = HidP_GetButtonCaps(HidP_Input, caps.as_mut_ptr(), &mut len, p as _);
-                    if ret != HIDP_STATUS_SUCCESS {
+                    if HidP_GetButtonCaps(HidP_Input, caps.as_mut_ptr(), &mut len, p as _).is_err() {
                         last_error!("HidP_GetButtonCaps");
                         return None;
                     }
                     caps
                 };
-                let button_num = if button_caps[0].IsRange != 0 {
+                let button_num = if button_caps[0].IsRange != BOOLEAN(0) {
                     let range = button_caps[0].Anonymous.Range;
                     (range.UsageMax - range.UsageMin + 1) as u32
                 } else {
@@ -282,8 +273,7 @@ pub fn get_device_info(device: &Device) -> Option<DeviceInfo> {
                     let mut len = caps.NumberInputValueCaps;
                     let mut caps = Vec::with_capacity(len as _);
                     caps.set_len(len as _);
-                    let ret = HidP_GetValueCaps(HidP_Input, caps.as_mut_ptr(), &mut len, p as _);
-                    if ret != HIDP_STATUS_SUCCESS {
+                    if HidP_GetValueCaps(HidP_Input, caps.as_mut_ptr(), &mut len, p as _).is_err() {
                         last_error!("HidP_GetValueCaps");
                         return None;
                     }
@@ -294,7 +284,7 @@ pub fn get_device_info(device: &Device) -> Option<DeviceInfo> {
                     ..Default::default()
                 };
                 for caps in &value_caps {
-                    let usage = if caps.IsRange == 0 {
+                    let usage = if caps.IsRange == BOOLEAN(0) {
                         caps.Anonymous.NotRange.Usage
                     } else {
                         continue;
@@ -374,15 +364,14 @@ unsafe fn register_gamepad_context(device: &Device) {
         }
         let p = preparsed.as_mut_ptr() as _;
         let mut caps = HIDP_CAPS::default();
-        if HidP_GetCaps(p, &mut caps) != HIDP_STATUS_SUCCESS {
+        if HidP_GetCaps(p, &mut caps).is_err() {
             return;
         }
         let button_caps = {
             let mut len = caps.NumberInputButtonCaps;
             let mut caps = Vec::with_capacity(len as _);
             caps.set_len(len as _);
-            let ret = HidP_GetButtonCaps(HidP_Input, caps.as_mut_ptr(), &mut len, p);
-            if ret != HIDP_STATUS_SUCCESS {
+            if HidP_GetButtonCaps(HidP_Input, caps.as_mut_ptr(), &mut len, p).is_err() {
                 return;
             }
             caps
@@ -391,8 +380,7 @@ unsafe fn register_gamepad_context(device: &Device) {
             let mut len = caps.NumberInputValueCaps;
             let mut caps = Vec::with_capacity(len as _);
             caps.set_len(len as _);
-            let ret = HidP_GetValueCaps(HidP_Input, caps.as_mut_ptr(), &mut len, p);
-            if ret != HIDP_STATUS_SUCCESS {
+            if HidP_GetValueCaps(HidP_Input, caps.as_mut_ptr(), &mut len, p).is_err() {
                 return;
             }
             caps
@@ -431,14 +419,13 @@ impl From<WPARAM> for WindowState {
 }
 
 pub(crate) fn register_devices(wnd: &Window, state: WindowState) {
-    let flags = RAWINPUTDEVICE_FLAGS(
-        RIDEV_DEVNOTIFY.0
-            | if state == WindowState::Background {
-                RIDEV_INPUTSINK.0
-            } else {
-                0
-            },
-    );
+    let flags = {
+        RIDEV_DEVNOTIFY | if state == WindowState::Background {
+            RIDEV_INPUTSINK
+        } else {
+            0
+        }
+    };
     let mut device = [
         RAWINPUTDEVICE {
             usUsagePage: HID_USAGE_PAGE_GENERIC,
@@ -714,7 +701,7 @@ unsafe fn input_data_gamepad(input: &mut RAWINPUT) -> Option<InputData> {
             PSTR(hid.bRawData.as_mut_ptr()),
             hid.dwSizeHid,
         );
-        if ret != HIDP_STATUS_SUCCESS {
+        if ret.is_err() {
             return None;
         }
         {
@@ -722,7 +709,7 @@ unsafe fn input_data_gamepad(input: &mut RAWINPUT) -> Option<InputData> {
             for btn in buttons.iter_mut() {
                 *btn = false;
             }
-            let range = if ctx.button_caps[0].IsRange != 0 {
+            let range = if ctx.button_caps[0].IsRange != BOOLEAN(0) {
                 ctx.button_caps[0].Anonymous.Range.UsageMin
             } else {
                 ctx.button_caps[0].Anonymous.NotRange.Usage
@@ -740,7 +727,7 @@ unsafe fn input_data_gamepad(input: &mut RAWINPUT) -> Option<InputData> {
         let mut hat = 0;
         for caps in &ctx.value_caps {
             let mut value = 0;
-            let usage = if caps.IsRange != 0 {
+            let usage = if caps.IsRange != BOOLEAN(0) {
                 caps.Anonymous.Range.UsageMin
             } else {
                 caps.Anonymous.NotRange.Usage
@@ -755,7 +742,7 @@ unsafe fn input_data_gamepad(input: &mut RAWINPUT) -> Option<InputData> {
                 PSTR(hid.bRawData.as_mut_ptr()),
                 hid.dwSizeHid,
             );
-            if ret != HIDP_STATUS_SUCCESS {
+            if ret.is_err() {
                 continue;
             }
             let value = value as i32;
