@@ -1,4 +1,7 @@
-use crate::bindings::Windows::Win32::{Foundation::*, UI::Controls::*, UI::WindowsAndMessaging::*};
+use windows::Win32::{
+    Foundation::*,
+    UI::WindowsAndMessaging::*,
+};
 use std::path::{Path, PathBuf};
 
 #[inline]
@@ -28,7 +31,7 @@ fn load_icon_impl(hinst: HINSTANCE, icon: &Icon, cx: i32, cy: i32) -> HICON {
                 LoadImageW(hinst, make_int_resource(*id), IMAGE_ICON, cx, cy, LR_SHARED)
             }
             Icon::File(path) => LoadImageW(
-                HINSTANCE::NULL,
+                HINSTANCE(0),
                 path.to_string_lossy().as_ref(),
                 IMAGE_ICON,
                 cx,
@@ -37,7 +40,7 @@ fn load_icon_impl(hinst: HINSTANCE, icon: &Icon, cx: i32, cy: i32) -> HICON {
             ),
         }
     };
-    if icon == HANDLE::NULL {
+    if icon == HANDLE(0) {
         panic!("cannot load the icon");
     }
     HICON(icon.0)
