@@ -1,5 +1,9 @@
-use crate::bindings::Windows::Win32::{
-    Foundation::*, Graphics::Gdi::*, System::LibraryLoader::*, UI::HiDpi::*, UI::Shell::*,
+use windows::Win32::{
+    Foundation::*,
+    Graphics::Gdi::*,
+    System::LibraryLoader::*,
+    UI::HiDpi::*,
+    UI::Shell::*,
     UI::WindowsAndMessaging::*,
 };
 #[cfg(feature = "raw_input")]
@@ -16,7 +20,7 @@ use crate::{
     procedure::{window_proc, UserMessage},
     resource::*,
 };
-use raw_window_handle::{windows::WindowsHandle, HasRawWindowHandle, RawWindowHandle};
+use raw_window_handle::{Win32Handle, HasRawWindowHandle, RawWindowHandle};
 use std::cell::RefCell;
 use std::rc::Rc;
 use std::sync::{Arc, RwLock};
@@ -32,7 +36,7 @@ pub trait Style {
     fn value(&self) -> u32;
 
     fn is_borderless(&self) -> bool {
-        self.value() == WS_POPUP.0
+        self.value() == WS_POPUP
     }
 }
 
@@ -41,7 +45,7 @@ pub struct BorderlessStyle;
 
 impl Style for BorderlessStyle {
     fn value(&self) -> u32 {
-        WS_POPUP.0
+        WS_POPUP
     }
 }
 
@@ -51,7 +55,7 @@ pub struct WindowStyle(u32);
 impl WindowStyle {
     #[inline]
     pub fn dialog() -> Self {
-        Self(WS_OVERLAPPED.0 | WS_CAPTION.0 | WS_SYSMENU.0)
+        Self(WS_OVERLAPPED | WS_CAPTION | WS_SYSMENU)
     }
 
     #[inline]
@@ -62,9 +66,9 @@ impl WindowStyle {
     #[inline]
     pub fn resizable(mut self, resizable: bool) -> Self {
         if resizable {
-            self.0 |= WS_THICKFRAME.0;
+            self.0 |= WS_THICKFRAME;
         } else {
-            self.0 &= !WS_THICKFRAME.0;
+            self.0 &= !WS_THICKFRAME;
         }
         self
     }
@@ -72,9 +76,9 @@ impl WindowStyle {
     #[inline]
     pub fn has_minimize_box(mut self, has_minimize_box: bool) -> Self {
         if has_minimize_box {
-            self.0 |= WS_MINIMIZEBOX.0;
+            self.0 |= WS_MINIMIZEBOX;
         } else {
-            self.0 &= !WS_MINIMIZEBOX.0;
+            self.0 &= !WS_MINIMIZEBOX;
         }
         self
     }
@@ -82,16 +86,16 @@ impl WindowStyle {
     #[inline]
     pub fn has_maximize_box(mut self, has_maximize_box: bool) -> Self {
         if has_maximize_box {
-            self.0 |= WS_MAXIMIZEBOX.0;
+            self.0 |= WS_MAXIMIZEBOX;
         } else {
-            self.0 &= !WS_MAXIMIZEBOX.0;
+            self.0 &= !WS_MAXIMIZEBOX;
         }
         self
     }
 
     #[inline]
     pub fn is_borderless(&self) -> bool {
-        self.value() == WS_POPUP.0
+        self.value() == WS_POPUP
     }
 }
 
@@ -99,12 +103,12 @@ impl Default for WindowStyle {
     #[inline]
     fn default() -> Self {
         Self(
-            WS_OVERLAPPED.0
-                | WS_CAPTION.0
-                | WS_SYSMENU.0
-                | WS_THICKFRAME.0
-                | WS_MINIMIZEBOX.0
-                | WS_MAXIMIZEBOX.0,
+            WS_OVERLAPPED
+                | WS_CAPTION
+                | WS_SYSMENU
+                | WS_THICKFRAME
+                | WS_MINIMIZEBOX
+                | WS_MAXIMIZEBOX,
         )
     }
 }
@@ -125,17 +129,17 @@ pub(crate) fn register_class<T: EventHandler + 'static>() {
             .collect::<Vec<_>>();
         let wc = WNDCLASSEXW {
             cbSize: std::mem::size_of::<WNDCLASSEXW>() as _,
-            style: WNDCLASS_STYLES(CS_VREDRAW.0 | CS_HREDRAW.0),
+            style: CS_VREDRAW | CS_HREDRAW,
             lpfnWndProc: Some(window_proc::<T>),
             cbClsExtra: 0,
             cbWndExtra: 0,
-            hInstance: GetModuleHandleW(PWSTR::NULL),
-            hIcon: HICON::NULL,
-            hCursor: HCURSOR::NULL,
+            hInstance: GetModuleHandleW(PWSTR::default()),
+            hIcon: HICON(0),
+            hCursor: HCURSOR(0),
             hbrBackground: HBRUSH(GetStockObject(WHITE_BRUSH).0),
-            lpszMenuName: PWSTR::NULL,
+            lpszMenuName: PWSTR::default(),
             lpszClassName: PWSTR(class_name.as_ptr() as _),
-            hIconSm: HICON::NULL,
+            hIconSm: HICON(0),
         };
         if RegisterClassExW(&wc) == 0 {
             panic!("cannot register the window class");
@@ -323,26 +327,26 @@ where
             let dpi = get_dpi_from_point(self.position);
             let inner_size = self.inner_size.to_physical(dpi);
             let rc = adjust_window_rect(inner_size, self.style, 0, dpi);
-            let hinst = GetModuleHandleW(PWSTR::NULL);
+            let hinst = GetModuleHandleW(PWSTR::default());
             let hwnd = CreateWindowExW(
                 if self.no_redirection_bitmap {
                     WS_EX_NOREDIRECTIONBITMAP
                 } else {
-                    WINDOW_EX_STYLE(0)
+                    0
                 },
                 WINDOW_CLASS_NAME,
                 self.title.as_ref(),
-                WINDOW_STYLE(self.style),
+                self.style,
                 self.position.x,
                 self.position.y,
                 (rc.right - rc.left) as i32,
                 (rc.bottom - rc.top) as i32,
-                HWND::NULL,
-                HMENU::NULL,
+                HWND(0),
+                HMENU(0),
                 hinst,
                 std::ptr::null_mut(),
             );
-            if hwnd == HWND::NULL {
+            if hwnd == HWND(0) {
                 return Err(ApiError::new());
             }
             let window = LocalWindow::new(
@@ -499,30 +503,30 @@ where
             let dpi = self.parent.dpi();
             let position = self.position.to_physical(dpi as i32);
             let size = self.size.to_physical(dpi);
-            let rc = adjust_window_rect(size, WS_CHILD.0, 0, dpi);
-            let hinst = GetModuleHandleW(PWSTR::NULL);
+            let rc = adjust_window_rect(size, WS_CHILD, 0, dpi);
+            let hinst = GetModuleHandleW(PWSTR::default());
             let hwnd = CreateWindowExW(
-                WINDOW_EX_STYLE(0),
+                0,
                 WINDOW_CLASS_NAME,
-                PWSTR::NULL,
+                PWSTR::default(),
                 WS_CHILD,
                 position.x,
                 position.y,
                 (rc.right - rc.left) as i32,
                 (rc.bottom - rc.top) as i32,
                 HWND(self.parent.raw_handle() as _),
-                HMENU::NULL,
+                HMENU(0),
                 hinst,
                 std::ptr::null_mut(),
             );
-            if hwnd == HWND::NULL {
+            if hwnd == HWND(0) {
                 return Err(ApiError::new());
             }
             let window = LocalWindow::new(
                 hwnd,
                 WindowState {
                     title: String::new(),
-                    style: WS_CHILD.0,
+                    style: WS_CHILD,
                     set_position: (position.x, position.y),
                     set_inner_size: size,
                     enabled_ime: self.parent.is_enabled_ime(),
@@ -659,19 +663,19 @@ impl Window {
 
     pub fn show(&self) {
         unsafe {
-            ShowWindowAsync(self.hwnd.0, SW_SHOW.0 as _);
+            ShowWindowAsync(self.hwnd.0, SW_SHOW);
         }
     }
 
     pub fn hide(&self) {
         unsafe {
-            ShowWindowAsync(self.hwnd.0, SW_HIDE.0 as _);
+            ShowWindowAsync(self.hwnd.0, SW_HIDE);
         }
     }
 
     pub fn redraw(&self) {
         unsafe {
-            RedrawWindow(self.hwnd.0, std::ptr::null(), HRGN::NULL, RDW_INTERNALPAINT);
+            RedrawWindow(self.hwnd.0, std::ptr::null(), HRGN(0), RDW_INTERNALPAINT);
         }
     }
 
@@ -787,10 +791,11 @@ impl Eq for Window {}
 
 unsafe impl HasRawWindowHandle for Window {
     fn raw_window_handle(&self) -> RawWindowHandle {
-        RawWindowHandle::Windows(WindowsHandle {
-            hinstance: unsafe { GetModuleHandleW(PWSTR::NULL).0 as _ },
-            hwnd: self.hwnd.0 .0 as _,
-            ..WindowsHandle::empty()
-        })
+        let mut handle = Win32Handle::empty();
+        handle.hinstance = unsafe {
+            GetModuleHandleW(PWSTR::default()).0 as *mut std::ffi::c_void
+        };
+        handle.hwnd = self.hwnd.0.0 as *mut std::ffi::c_void;
+        RawWindowHandle::Win32(handle)
     }
 }
